# This file includes an example use of every Swallow preference. It's
# for reference, see typical.swallowprefs.py for an example of
# something more like real-world use.

# This file is Python code though Swallow intentionally tries to make
# simple setups easy to do. If you need help with Python, please see
# the excellent documentation at www.python.org.

# Since this file is Python, it can do anything that you're allowed to
# do when it's read. Swallow tries to make sure tht the permissions
# are reasonable but that's no substitute for being careful about what
# gets in here.

# Swallow allows preferences to vary by "location". If you have only
# one location, you don't need to use locations. Preferences that are
# given as simple assignment statements are global. If any preferences
# that are global are re-defined for a given location (examples near
# bottom), the location preference takes precedence if that location
# is currently set.

# So if you have only one location, all preferences can be simple
# assignements. If you have more than one location, some preferences
# can be simple assignments and thus apply everywhere (e.g. your name)
# and some can be assigned to particular locations (e.g. your mail
# server). Examples of preferences specific to locations are given
# at the bottom.

# When Swallow starts, if more than one location is defined, the
# current location is set to the value of the global preference
# defaultLocation if that preference exists. If it doesn't, the curent
# location is set to the value that results from calling the
# parameterless function getDefaultLocation that's also a global
# preference. If getDefaultLocation also doesn't exist, the current
# location is set arbitrarily.

# Since defining a Python function doesn't involve explicitly
# assigning the code to a name (not myFunc=func()...), preferences
# that take values that are functions work a bit differently from
# preferences that take other sorts of values such as character
# strings and numbers.  When you define a function in Python (def
# myFunc(): ...), you're essentailly binding the code to a particular
# name (myFunc in the example). So when you want to specify a global
# preference that takes a function as its value, all you need to do is
# to define that function in the file. The def statement has to be at
# the top level (i.e. flush left).

# If you want to define a function that is the value of a location
# preference (not often necessary), there's no direct way to do
# it. Instead, define a function at the top level and then assign the
# name to the relevant location preference. If, for some reason, you
# don't want the function to be a global prefrence value, use a
# different name. Something like:
#
# def myFunc():
#   return "wibble"
# park=location()
# park.prefThatWantsFunc=myFunc



# We can import any modules that are necessary 
import socket
import os
import time

# Not a preference, rather a utility function used in getSaveFolders
# below

def addIfNotPresent(list,item):
  if item not in list:
    list.append(item)


# Function to sort mailbox names. This is the default:

def mailboxNamesSortFunc(listOfNames):
  listOfNames.remove("inbox")
  listOfNames.remove("outbox")
  listOfNames.remove("trash")
  listOfNames.sort()
  listOfNames.insert(0,"trash")
  listOfNames.insert(0,"outbox")
  listOfNames.insert(0,"inbox")
  return listOfNames


# Function to decide where to put mail that's saved with key "s" or
# plain Save in menu. Return either a string or a list of strings.
# Default is a function that always returns "saved". For reasons of
# efficiency, the mail object that's the argument is produced by the
# email module's HeaderParser and the body of the message isn't
# available.

def getSaveFoldersInbound(msg):
  # I like to archive my mail by month so always return
  # something like mail-2000-06
  mbs=[time.strftime("mail-%Y-%m",time.localtime(time.time()))]
  # Sometimes also save in other folders. Folders need not exist
  # already
  if msg.get("from","").lower().find("my-buddy@example.com")<>-1:
    addIfNotPresent(mbs,"my-buddy")
  if msg.get("to","").lower().find("my-buddy@example.com")<>-1:
    addIfNotPresent(mbs,"my-buddy")
  return mbs


# Just as above but it's called "(Alternate per prefs)" and is on the
# a and A keys. Just an alternative in case you have a use for two.
# Could be used, for example, to accumulate spam for automated
# analysis. If set to a false value, menu item doesn't show up and a,
# A keys don't do anything. Default None.

def getSaveFoldersInboundAlt(msg):
  return "spam"


# Function to decide where to put mail that's sent. Default is as
# below. You might want something more like the example for
# getSaveFoldersOutbound above. To disable saving sent mail, set to
# None. As with the corresponding function above, only the messages's
# headers are available.

def getSaveFoldersOutbound(msg):
  return ["sent"]


# Function to set up replies. Called with an instance of the email
# module's Message class containing the message as Swallow would
# normally set up the reply. The function could add or change headers,
# fiddle the body, etc.

def replyMunger(emailObj):
  if emailObj["subject"].lower().find("[some-mailing-list])<>-1:
    emailObj["cc"]="list@example.com"
    emailObj["reply-to"]="list@example.com"
  return None

# forwardMunger, newMailMunger just as above


# Function to determine where an inbound message should be saved.
# Called with an instance of the email module's Message object. Return
# a list of the names of the mailboxes to move it to.  If you only
# want to move it to one mailbox, you can just return a string. Return
# None or "inbox" to leave the message in the inbox. If you want to
# leave it in the inbox and copy it to another mailbox, return "inbox"
# as one of the items in the list.

def inboundFiler(emailObj):
  if emailObj["subject"].lower().find("[some-mailing-list]")<>-1:
    return ["this-list"]
  return None


# Function to determine mail's score. Score can be used in sorting
# mailboxes: If threading is not turned on, lines in the overview are
# sorted by score then date. If threading is turned on, sibling
# messages are sorted into threads and message trees are sorted so
# that trees with higher average scores come first. If a POP session
# retrieves an email with a score higher than noisyScore,
# doHighScoreThing is called. The argument is a Message instance from
# the email module but only the headers should be used. The message
# body may not be available.

def calculateScore(mailObj):
  # Mail from my buddy is gets score 10
  if mailObj.get("from","").lower().find("my-buddy@example.com")<>-1:
    return 10
  # Mail to or cc-ed to me gets score 5
  if mailObj.get("to","").lower().find("me@example.org")<>-1:
    return 5
  if mailObj.get("cc","").lower().find("me@example.org")<>-1:
    return 5
  return 0


# The default mailbox sort order can be controlled in either of two
# ways: you can either set a dictionary that specifies the default for
# all mailboxes or you can specify a function that takes the mailbox
# name as an argument and returns the dictionary to be used. If you
# define both, Swallow will complain and use the function. If the user
# changes the sort order, Swallow remembers the last sort order chosen
# in ~/.swallowstate.pickle so the default is only used for new
# mailboxes or if that file is deleted. The dict should have three
# keys: "thread", "score", and "date". The values for thread and score
# should be booleans and the value for date should be either
# "ascending" or "descending". The default for score is true if the
# function calculateScore has been defined and false otherwise. The
# default for thread is true and for date is "ascending".

defaultMailboxSort={"thread": 1, "score": 1, "date": "ascending"}

# The function takes the mailbox name as its parameter and should
# return a dict as above.

getDefaultMailboxSort(mailboxName):
  if mailboxName=="inbox":
    return {"thread": 1, "score": 1, "date": "ascending"}
  else:
    return {"thread": 0, "score": 0, "date": "descending"}


# Function to determine current default location on startup. Ordinary
# preference defaultLocation takes precedence.

def getDefaultLocation(self):
  # Note that this technique for determining the local IP
  # may or may not work, depending on the exact way your
  # networking is set up. That's inherent in TCP/IP and
  # isn't Python's fault. Parsing the output of ifconfig
  # is another useful technique.
  fqdn=socket.getfqdn()
  hostOnly=fqdn.split(".")[0]
  # If I use the FQDN here, I get back 127.0.0.1 but
  # I get the right answer if I give the host only.
  ip=socket.gethostbyname(hostOnly)

  if ip=="192.200.9.90":
    return "office"

  if ip=="10.10.10.10":
    return "home"

  # This is prolly specific to Linux but I suspect that a similar
  # thing could be done under most other Unixes, perhaps by opening
  # a pipe from ifconfig.
  if os.path.isfile("/proc/net/route"):
    f=open("/proc/net/route")
    l=f.readline()
    while l<>"":
      i=l.split()
      if i[0]=="ppp0":
        f.close()
        return "ppp"
      l=f.readline()
    f.close()
  # Give up
  return ""


# Primitive addressbook. The nickname "me" is added automtically. No
# automatic import written, you must edit here in prefs. For more
# sophisticated addressbook, install MetaKit and set preference
# swdbfile.

addressbookData= \
  (
  # Nickaname, address. Nicknames may not have "@"s or
  # spaces. Nicknames entered in mail editor address
  # fields are expanded to the corresponding address.
  # The reverse is done in the overview.
  ("example", '"Example E. Example" <example@example.org>'),
  ("anotherexample", "Another Example <example@example.com>"),
  )


# Simple preference, mostly obvious

myMailAddress="example@example.org"

myHumanName="Swallow user"


# Reply-to header in outbound mail, default is no reply-to.  It can be
# edited in the mail editor. Could be added or changed by replyMunger
# forwardMunger, newMailMunger

replyTo="otheraddress@example.org"


# Temp directory to use, default as below

tempDir=os.path.expanduser("~/swallow/temp")


# Fully-qalified domain name, default is whatever
# socket.getfqdn() returns

fqdn="lawnboy.example.com"


# Log file path beginning, default is ~/swallow/temp/swallowlog
# (i.e. in the default temp directory). Use None to disable
# saving the log. A new log file is created at each startup. The
# name has -yyyymmdd-hhmmss appended to it. Swallow cleans up
# files from the temp directory after a week.

logFilePath=os.path.expanduser("~/swallow/temp/swallowlog")


# Integer, default 99. If calculateScore returns value >= this value
# on new mail, doHighScoreThing callback executed.

noisyScore=5


# Callback, default do nothing. Could be a proper function of the
# same name

doHighScoreThing= \
  lambda: os.system("/usr/bin/play /usr/share/sounds/phone.wav &")


# Tuple of color names, for sendable, draft, not sendable; defualt as below

outboxColors=("black","blue","red")


# Directory that contains your Maildir, default as below

maildirParent=os.path.expanduser("~")


# Headers to show by defaul in mail viewer, default as below

nonBoringHeaders=("from","to","cc","bcc","subject","date","reply-to")


# Where to put outbox, saved mail folders, etc. Default as below

userMailboxDirParent"=os.path.expanduser("~/Mail")


# 1 or 0, default 0

emptyTrashOnQuit=0


# Fonts to use, defaults as below

fontILike="7x13"
fixedWidthFontILike="7x13"
boldFontILike="7x13bold"


# Mail specified number of days old in specified mailbox will be moved to
# trash mailbox on quit. Done after empty trash on quit if that's turned
# on so you'll have a chance to get it back out. Tuple of tuples:
# mailbox name, days old; default empty (don't do anything). If
# emptyTrashOnQuit is set to 1, trash is emptied before mail is moved
# to trash so you get an opportunity to move it back out.

autoTrash=(("current",30),)


# Where is ispell? Default as below

ispellLoc="/usr/bin/ispell"


# Spelling checker highlights space runs. As a typographer
# I deplore using two spaces after a period but lots of folks
# do it. Set to 1 to only highlight runs of 3 or more spaces.
# Default 0

twoSpacesOK=0


# Colors for text foreground for things highlighted by spelling
# check. First is for unrecognized words that ispell has suggestions
# for, second is for unrecognized words that ispell has no
# suggestions for, third is for space runs.
# Default as below

spellingCheckColors=("red","purple","yellow1"),


# Colors (fg,bg) to highlight text search matches in mail viewer
# Default as below

textSearchColors=("white","blue"),


# Location of your signature file. Default None. None or "" mean
# don't add signature. Often os.path.expanduser("~/.signature)
# is what someone might want.

sigFile=None


# When user asks to print mail, text is piped to this command. Default
# is "/bin/cat > /dev/null". You may want something more like item below.

printCommand="/usr/bin/lpr"


# Command to pipe mail to. Invoked by key "|" in mail viewer window.
# Default is None (i.e. do nothing). I use it to pipe the mail
# to an external spam review helper. Note that unlike printCommand,
# it's the raw mail that's sent to the pipe, not necessarily what's
# being shown in the viewer.

pipeCommand=os.path.expanduser("~/swallow/spamgrep.py")


# Setting this one to the name of a datafile to use enables the
# more-complex version of the addressbook. See README.swdb for
# the details.

swdbFile=os.path.expanduser("~/swallow/addresses")


# If mail is larger in bytes than this value, don't fetch it. Instead
# inform user and allow it to be fetched later if desired. The default
# is 10M. Note that the constant kNeverFetchBiggerThan in swallow.py
# will override this value if it's smaller. There is no trivial way
# to fetch all mail regardless of size. See the caution in the readme
# about Swallow storing mail in memory.
# Default 10M as below:

askBeforeFetchingMailThisBig=10*1024*1024


# Lines in viewer that describe MIME parts are highlighted
# according to these settings. Defaults as below.

mimeCommentaryFG="white"
mimeCommentaryBG="black"


# If mail is delivered to your Maildir by some other program, you can
# set this item to "scan" so that checking for mail just inspects the
# inbox. Default is "pop".

mailCheckAction="pop"


# Width at which to wrap outgoing mail, default as below:

outboundMailWrapLen=70


# Should Swallow sanity-check outbound mail? Could complain about
# some legitimate mail. Default true.

sanityCheckOutboundMail=1


# In the mail editor, the rewrap button re-wraps the user's
# text to the appropriate margin. So that:
#
# > Hi, how is your new house?
# > I remember that you said that
# Send help!
# The llamas have escaped!
#
# is wrapped more attractively as:
#
# > Hi, how is your new house? I remember that you said that
# Send help! The llamas have escaped!
#
# But if you regularly start emails with a line like "Dear Bruce,"
# the next line would be wrapped up on to that line, which is
# probably not what you want. This preference controls special-
# casing of such a line. If set to true (the default), if the
# message's first line is short (<=30 characters) and ends with
# any of comma, colon, dash, semi-colon, or bang, it's not rewrapped
# unless the insertion point is in it or it's part of the selection.

specialCaseRewrapDearLine=1


# If the mouse pointer is over a widget you're typing into, Swallow
# can hide the pointer so that it's easier to see what you're typing.
# The pointer is un-hidden as soon as you move the mouse. Default
# off.

hideMousePointerWhileTyping"=0


# Should automatic checking for new mail be turned on at startup?
# Default no.

autoStartCheckRegularly=0


# Colors for foreground of quoted text in viewer (unquoted text
# remains black). First color used for singly-quoted text, second
# for doubly-quoted, etc. As many as you like allowed, last one
# used for all deeper levels. Default None, don't color quotes.

viewerQuoteColors=("navy","darkgreen","gray25")


# When replying, if swdb used, should Swallow get the name from Swdb
# or use the one in the original header? Default 0.

useSWDBNameOnReply=0


# Defining loctaions. The one corresponding to defaultLocation or the
# value returned by getDefaultLocation is set at startup. Location
# prefs are searched before global prefs. Any item may be in either
# place. These are shown as location preferences only because they're
# more likely to vary. If you only need one location, you could
# dispense with home=location() and just say

# mailserver="mail.example.org".


home=location()

# Serves only as the default for the next two

home.mailServer="mail.example.org"


# Default is mailServer above

home.smtpServer="mail.example.org"


# Default is mailServer above

home.popServer="mail.example.org"


# Default is 25

home.smtpPort=25

# Default is False

home.smtpTLS=False

# Default is False and no value for user and password

home.smtpAuth=False
# home.smtpUser="me"
# home.smtpPass="bigsecret"s

# Default is False

home.popSSL=False

# Default is 110 unless popSSL set to true. Then it's 995.

home.popPort=1100


# Default is environment variable LOGNAME.

home.popUser="testuser"


# If listed here, is rot13-ed before use. (Tiny rot13.py utility included
# for convenience.) Not for security, just to prevent casual glances from
# revealing passwords. Default is None. None and "" mean ask each time.

home.popPass="furrfu"


# userpass or apop, default is userpass

home.popAuth="apop"


# 1 or 0, default is 1

home.popDele=1


# Delay between checks if Check regularly turned on;
# Seconds, default 300

home.checkDelay=60


office=location()
office.mailServer="mail.example.com"
office.popPass="cnffjbeq" # rot-13d
office.popAuth="userpass"
office.checkDelay=120
office.autoStartCheckRegularly=1

ppp.smtpServer="smtp.example.com"
ppp.popServer="pop.example.com"
ppp.popUser="dialup-user"
ppp.popPass=""
ppp.popDele=0
ppp.autoStartCheckRegularly=0
