# This is intended as an example of a typical preferences file for
# Swallow. (It's a slightly modified version of my own.) It's more
# than what's necessary to get going (that's minimal.swallowprefs.py)
# but it doesn't list every possible preference setting (that's
# complete.swallowprefs.py). Someone who needs preferences settings
# that aren't in the minimal set shouldn't have to wade through
# everything to see what's routinely useful.

# This is Python code and it's read at startup so it can do anything
# that you're allowed to do. Swallow tries to make sure that the
# permissions on its preferences file are reasonable but that's no
# substitute for being careful about what gets in here.


# Import some modules we'll want. Merely convention to do this at the
# top.

import os
import re
import time


# Note that the preferences that are functions below are Python that
# are executed by Swallow. You can crash Swallow if they have bugs in
# them. Swallow tries hard not to lose mail if it crashes but test
# carefully.

# A utility function we'll use later.

def addIfNotPresent(list,item):
  if item not in list:
    list.append(item)


# SWDB (inspired by BBDB) records every address it sees. To prevent
# its database from growing without limit, it has a menu choice
# "Delete uninteresting". Here's how it decides what you think is
# interesting.

def swdbShouldKeepFunc(item):
  if item.nick<>"":
    return 1
  if item.comments<>"":
    return 1
  if item.dateLastHeardFrom>=time.time()-(60*60*24*30):
    return 1
  if item.dateLastMailedTo<>0:
    return 1
  return 0


# The default order in which mailboxes appear is inbox, outbox, trash,
# and then the rest in alphabetical order. If you'd like another
# order, here's how you determine it.

def mailboxNamesSortFunc(listOfNames):
  exampleMailboxExists=listOfNames.count("example-mailbox")>0
  if exampleMailboxExists:
    listOfNames.remove("example-mailbox")
  listOfNames.remove("inbox")
  listOfNames.remove("outbox")
  listOfNames.remove("trash")
  listOfNames.sort()
  if exampleMailboxExists:
    listOfNames.insert(0,"example-mailbox")
  listOfNames.insert(0,"trash")
  listOfNames.insert(0,"outbox")
  listOfNames.insert(0,"inbox")
  return listOfNames


# When you save mail by just hitting "s" (or "S") or by choosing
# (Default per prefs) from the menu, mail is saved to "saved".  I
# prefer to use mailbox names that change by month rather than having
# one mailbox that grows endlessly. Input is one of Swallow's message
# objects and output is a list of mailbox names. For reasons of
# efficiency the mail object that's the argument here is produced by
# the email module's HeaderParser. The message's body isn't available.
# The email module is documented at:
#
# http://www.python.org/doc/current/lib/module-email.html

def getSaveFoldersInbound(msg):
  # I always include a mailbox of the sort "mail-2002-09"
  mbs=[time.strftime("mail-%Y-%m",time.localtime(time.time()))]
  if msg.get("from","").lower().find("my-buddy@example.com")<>-1:
    addIfNotPresent(mbs,"my-buddy")
  if msg.get("to","").lower().find("my-buddy@example.com")<>-1:
    addIfNotPresent(mbs,"my-buddy")
  if msg.get("Subject","").find("[some-mailing-list]")<>-1:
    addIfNotPresent(mbs,time.strftime("ml-%Y-%m",time.localtime(time.time())))
  return mbs


# By default, sent mail is saved to the mailbox "sent". I prefer to
# save it to the same mailboxes that I use for saving incoming mail.

getSaveFoldersOutbound=getSaveFoldersInbound


# Swallow can do something when it receives mail that has a score
# above some value that you specify. And higher-scored mail always
# sorts toward the top. For reasons of efficiency the mail object
# that's the argument here is produced by the email module's
# HeaderParser.  The message's body isn't available. The email module
# is documented at:
#
# http://www.python.org/doc/current/lib/module-email.html

def calculateScore(mailObj):
  if mailObj.get("from","").lower().find("my-buddy@example.com")<>-1:
    return 10
  if mailObj.get("to","").lower().find("my-address@example.org")<>-1:
    return 5
  return 0


# When replying (or forwarding or creating new mail) it's possible to
# make changes in the default message that you edit. Functions
# defaultForwardMunger and defaultNewMailMunger work similarly. Could
# be used to add random signature for example. Argument is an instance
# of the Message class from the email module. The module is documented
# at:
#
# http://www.python.org/doc/current/lib/module-email.html

def replyMunger(msgInstance):
  if msgInstance["Subject"].lower().find("[wibble]")<>-1:
    msgInstance["cc"]="example@example.com"
    msgInstance["reply-to"]="example.example.org"
  return None


# Some preferences in this file change based on location. I could
# specify defaultLocation to set one location as the default on every
# startup. Instead, this code determines the default.

def getDefaultLocation():
  # This code might work for some folks but it doesn't for me
  #fqdn=socket.gethostname()
  #hostOnly=string.split(fqdn,".")[0]
  ## Dunno why but if I use the fqdn here, I get back 127.0.0.1 but
  ## I get the right answer if I give the host only.
  #try:
  #  ip=socket.gethostbyname(hostOnly)
  #except socket.error:
  #  return ""
  p=os.popen("/sbin/ifconfig eth0")
  blob=p.read()
  p.close()
  m=re.search("inet addr:([^ ]+)",blob,re.MULTILINE)
  if m==None:
    return ""
  ip=m.group(1)

  if ip=="192.168.0.4":
    return "office"

  if ip=="10.0.0.4":
    return "home"

  # Another technique
  if os.path.isfile("/proc/net/route"):
    f=open("/proc/net/route")
    l=f.readline()
    while l<>"":
      i=l.split()
      if i[0]=="ppp0":
        f.close()
        return "ppp"
      l=f.readline()
    f.close()
  # Give up
  return ""

# Preferences that don't vary by location. Can also be defaults for
# preferences that vary in some locations.
myMailAddress="example@example.com"
myHumanName="Swallow user"
tempDir=os.path.expanduser("~/swallow/temp")
noisyScore=5
doHighScoreThing= \
  lambda: os.system("/usr/bin/play /usr/share/sounds/phone.wav &")
fontILike="neep-alt-12" # from http://www.ntrnet.net/~jmknoble/fonts/
fixedWidthFontILike="neep-alt-12"
boldFontILike="neep-alt-bold-12"
printCommand="/usr/bin/lpr"
swdbFile=os.path.expanduser("~/swallow/addresses")
useSWDBNameOnReply=1
pipeCommand=os.path.expanduser("~/swallow/spamgrep.py")
askBeforeFetchingMailThisBig=1024*1024
hideMousePointerWhileTyping=1
viewerQuoteColors=("navy","darkgreen","gray25")
threadMessagesDefault=1


home=location()
home.mailServer="server.example.com"
home.popUser="example"
home.popPass="furrfu"
home.popAuth="apop"
home.checkDelay=60
home.autoStartCheckRegularly=1

office=location()
office.mailServer="server.example.org"
office.popUser="example"
office.popPass=""
office.checkDelay=300
office.askBeforeFetchingMailThisBig=1024*1024

ppp=location()
ppp.smtpServer="smtp.example.com"
ppp.popServer="pop.example.com"
ppp.popUser="example"
ppp.popPass=""
ppp.popDele=0
ppp.popAuth="apop"
